LidWidgetBuilder<T> typedef
LidWidgetBuilder<T> =
Widget Function(BuildContext context, T value)
Signature for the builder function which takes the BuildContext and
the state value and is responsible for returning a widget which is to be rendered.
This is analogous to the builder function in StreamBuilder.
Implementation
typedef LidWidgetBuilder<T> = Widget Function(BuildContext context, T value);